@@ -4,4 +4,4 @@ source.with.err <- function(path) {
 	tryCatch(source(path), error = function(x) {print(path); print(x)})
 }
 
-lapply(dir("~/ggobi/rggobi-2.1/rggobi/R/", "\\.[Sr]$", full.name=T), source.with.err)
\ No newline at end of file
+lapply(dir("~/ggobi/rggobi/R/", "\\.[Sr]$", full.name=T), source.with.err)
\ No newline at end of file
